--------------------------------------------------------------------------------
-- |
-- Module      :  Graphics.Rendering.OpenGL.Raw.NV.TexgenReflection
-- Copyright   :  (c) Sven Panne 2015
-- License     :  BSD3
--
-- Maintainer  :  Sven Panne <svenpanne@gmail.com>
-- Stability   :  stable
-- Portability :  portable
--
-- The <https://www.opengl.org/registry/specs/NV/texgen_reflection.txt NV_texgen_reflection> extension.
--
--------------------------------------------------------------------------------

module Graphics.Rendering.OpenGL.Raw.NV.TexgenReflection (
  -- * Enums
  gl_NORMAL_MAP_NV,
  gl_REFLECTION_MAP_NV
) where

import Graphics.Rendering.OpenGL.Raw.Tokens
